summaryrefslogtreecommitdiffstats
path: root/test/dtypes.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/dtypes.c')
-rw-r--r--test/dtypes.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/dtypes.c b/test/dtypes.c
index f01c5e3..4ee4eec 100644
--- a/test/dtypes.c
+++ b/test/dtypes.c
@@ -4410,10 +4410,10 @@ test_latest(void)
FAIL_STACK_ERROR
/* Set the 'use the latest format' flag in the FAPL */
if((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
FAIL_STACK_ERROR
- if(H5Pset_latest_format(fapl, TRUE) < 0)
+ if(H5Pset_format_bounds(fapl, H5F_FORMAT_LATEST, H5F_FORMAT_LATEST) < 0)
FAIL_STACK_ERROR
/* Create file using default FAPL */
@@ -4410,10 +4410,10 @@ test_latest(void)
FAIL_STACK_ERROR
- /* Set the 'use the latest format' flag in the FAPL */
+ /* Set the 'use the latest format' bounds in the FAPL */
if((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
FAIL_STACK_ERROR